==> keyclic_sdk_api-2.2.12.tar.gz: lib/model/operation_links_operator_iri_template.dart <==
part of keyclic_sdk_api.api;

class OperationLinksOperatorIriTemplate {
  OperationLinksOperatorIriTemplate({
    this.mapping,
  });

  factory OperationLinksOperatorIriTemplate.fromJson(
      Map<String, dynamic> json) {
    if (json == null) {
      return null;
    }

    return OperationLinksOperatorIriTemplate(
      mapping: ContributionLinksContributorIriTemplateMapping.fromJson(
          json['mapping']),
    );
  }

  ContributionLinksContributorIriTemplateMapping mapping;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is OperationLinksOperatorIriTemplate &&
        runtimeType == other.runtimeType &&
        mapping == other.mapping;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= mapping?.hashCode ?? 0;

    return hashCode;
  }

  static List<OperationLinksOperatorIriTemplate> listFromJson(
      List<dynamic> json) {
    return json == null
        ? <OperationLinksOperatorIriTemplate>[]
        : json
            .map((dynamic value) =>
                OperationLinksOperatorIriTemplate.fromJson(value))
            .toList();
  }

  static Map<String, OperationLinksOperatorIriTemplate> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, OperationLinksOperatorIriTemplate>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = OperationLinksOperatorIriTemplate.fromJson(value));
    }

    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      if (mapping != null) 'mapping': mapping,
    };
  }

  @override
  String toString() {
    return 'OperationLinksOperatorIriTemplate[mapping=$mapping, ]';
  }
}

==> keyclic_sdk_api-2.3.8.tar.gz: lib/model/operation_links_operator_iri_template.dart <==
part of keyclic_sdk_api.api;

class OperationLinksOperatorIriTemplate {
  OperationLinksOperatorIriTemplate({
    this.mapping,
  });

  factory OperationLinksOperatorIriTemplate.fromJson(
      Map<String, dynamic> json) {
    if (json == null) {
      return null;
    }

    return OperationLinksOperatorIriTemplate(
      mapping: ContributionLinksContributorIriTemplateMapping.fromJson(
          json['mapping']),
    );
  }

  ContributionLinksContributorIriTemplateMapping mapping;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is OperationLinksOperatorIriTemplate &&
        runtimeType == other.runtimeType &&
        mapping == other.mapping;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= mapping?.hashCode ?? 0;

    return hashCode;
  }

  static List<OperationLinksOperatorIriTemplate> listFromJson(
      List<dynamic> json) {
    return json
            ?.map((dynamic value) =>
                OperationLinksOperatorIriTemplate.fromJson(value))
            ?.toList() ??
        <OperationLinksOperatorIriTemplate>[];
  }

  static Map<String, OperationLinksOperatorIriTemplate> mapFromJson(
      Map<String, dynamic> json) {
    return json?.map((String key, dynamic value) {
          return MapEntry(
              key, OperationLinksOperatorIriTemplate.fromJson(value));
        }) ??
        <String, OperationLinksOperatorIriTemplate>{};
  }

  Map<String, dynamic> toJson() {
    return {
      if (mapping != null) 'mapping': mapping.toJson(),
    };
  }

  @override
  String toString() {
    return 'OperationLinksOperatorIriTemplate[mapping=$mapping, ]';
  }
}
